@@ -56,7 +56,7 @@ void Database::Process() {
             queue.pop();
             std::unique_ptr<Baton> baton(call->baton);
             Napi::Function cb = baton->callback.Value();
-            if (!cb.IsUndefined() && cb.IsFunction()) {
+            if (IS_FUNCTION(cb)) {
                 TRY_CATCH_CALL(this->Value(), cb, 1, argv);
                 called = true;
             }
@@ -97,7 +97,7 @@ void Database::Schedule(Work_Callback callback, Baton* baton, bool exclusive) {
         // We don't call the actual callback, so we have to make sure that
         // the baton gets destroyed.
         delete baton;
-        if (!cb.IsUndefined() && cb.IsFunction()) {
+        if (IS_FUNCTION(cb)) {
             Napi::Value argv[] = { exception };
             TRY_CATCH_CALL(Value(), cb, 1, argv);
         }
@@ -202,7 +202,7 @@ void Database::Work_AfterOpen(napi_env e, napi_status status, void* data) {
 
     Napi::Function cb = baton->callback.Value();
 
-    if (!cb.IsUndefined() && cb.IsFunction()) {
+    if (IS_FUNCTION(cb)) {
         TRY_CATCH_CALL(db->Value(), cb, 1, argv);
     }
     else if (!db->open) {
@@ -294,7 +294,7 @@ void Database::Work_AfterClose(napi_env e, napi_status status, void* data) {
     Napi::Function cb = baton->callback.Value();
 
     // Fire callbacks.
-    if (!cb.IsUndefined() && cb.IsFunction()) {
+    if (IS_FUNCTION(cb)) {
         TRY_CATCH_CALL(db->Value(), cb, 1, argv);
     }
     else if (db->open) {
@@ -371,6 +371,27 @@ Napi::Value Database::Configure(const Napi::CallbackInfo& info) {
         baton->status = info[1].As<Napi::Number>().Int32Value();
         db->Schedule(SetBusyTimeout, baton);
     }
+    else if (info[0].StrictEquals( Napi::String::New(env, "limit"))) {
+        REQUIRE_ARGUMENTS(3);
+        if (!info[1].IsNumber()) {
+            Napi::TypeError::New(env, "limit id must be an integer").ThrowAsJavaScriptException();
+            return env.Null();
+        }
+        if (!info[2].IsNumber()) {
+            Napi::TypeError::New(env, "limit value must be an integer").ThrowAsJavaScriptException();
+            return env.Null();
+        }
+        Napi::Function handle;
+        int id = info[1].As<Napi::Number>().Int32Value();
+        int value = info[2].As<Napi::Number>().Int32Value();
+        Baton* baton = new LimitBaton(db, handle, id, value);
+        db->Schedule(SetLimit, baton);
+    }
+    else if (info[0].StrictEquals(Napi::String::New(env, "change"))) {
+        Napi::Function handle;
+        Baton* baton = new Baton(db, handle);
+        db->Schedule(RegisterUpdateCallback, baton);
+    }
     else {
         Napi::TypeError::New(env, (StringConcat(
 #if V8_MAJOR_VERSION > 6
@@ -415,6 +436,15 @@ void Database::SetBusyTimeout(Baton* b) {
     sqlite3_busy_timeout(baton->db->_handle, baton->status);
 }
 
+void Database::SetLimit(Baton* b) {
+    std::unique_ptr<LimitBaton> baton(static_cast<LimitBaton*>(b));
+
+    assert(baton->db->open);
+    assert(baton->db->_handle);
+
+    sqlite3_limit(baton->db->_handle, baton->id, baton->value);
+}
+
 void Database::RegisterTraceCallback(Baton* b) {
     std::unique_ptr<Baton> baton(b);
     assert(baton->db->open);
@@ -531,12 +561,13 @@ void Database::UpdateCallback(Database *db, UpdateInfo* i) {
     Napi::HandleScope scope(env);
 
     Napi::Value argv[] = {
+        Napi::String::New(env, "change"),
         Napi::String::New(env, sqlite_authorizer_string(info->type)),
         Napi::String::New(env, info->database.c_str()),
         Napi::String::New(env, info->table.c_str()),
         Napi::Number::New(env, info->rowid),
     };
-    EMIT_EVENT(db->Value(), 4, argv);
+    EMIT_EVENT(db->Value(), 5, argv);
 }
 
 Napi::Value Database::Exec(const Napi::CallbackInfo& info) {
@@ -599,7 +630,7 @@ void Database::Work_AfterExec(napi_env e, napi_status status, void* data) {
     if (baton->status != SQLITE_OK) {
         EXCEPTION(Napi::String::New(env, baton->message.c_str()), baton->status, exception);
 
-        if (!cb.IsUndefined() && cb.IsFunction()) {
+        if (IS_FUNCTION(cb)) {
             Napi::Value argv[] = { exception };
             TRY_CATCH_CALL(db->Value(), cb, 1, argv);
         }
@@ -608,7 +639,7 @@ void Database::Work_AfterExec(napi_env e, napi_status status, void* data) {
             EMIT_EVENT(db->Value(), 2, info);
         }
     }
-    else if (!cb.IsUndefined() && cb.IsFunction()) {
+    else if (IS_FUNCTION(cb)) {
         Napi::Value argv[] = { env.Null() };
         TRY_CATCH_CALL(db->Value(), cb, 1, argv);
     }
@@ -640,7 +671,7 @@ void Database::Work_Wait(Baton* b) {
     assert(baton->db->pending == 0);
 
     Napi::Function cb = baton->callback.Value();
-    if (!cb.IsUndefined() && cb.IsFunction()) {
+    if (IS_FUNCTION(cb)) {
         Napi::Value argv[] = { env.Null() };
         TRY_CATCH_CALL(baton->db->Value(), cb, 1, argv);
     }
@@ -711,7 +742,7 @@ void Database::Work_AfterLoadExtension(napi_env e, napi_status status, void* dat
     if (baton->status != SQLITE_OK) {
         EXCEPTION(Napi::String::New(env, baton->message.c_str()), baton->status, exception);
 
-        if (!cb.IsUndefined() && cb.IsFunction()) {
+        if (IS_FUNCTION(cb)) {
             Napi::Value argv[] = { exception };
             TRY_CATCH_CALL(db->Value(), cb, 1, argv);
         }
@@ -720,7 +751,7 @@ void Database::Work_AfterLoadExtension(napi_env e, napi_status status, void* dat
             EMIT_EVENT(db->Value(), 2, info);
         }
     }
-    else if (!cb.IsUndefined() && cb.IsFunction()) {
+    else if (IS_FUNCTION(cb)) {
         Napi::Value argv[] = { env.Null() };
         TRY_CATCH_CALL(db->Value(), cb, 1, argv);
     }
@@ -737,4 +768,8 @@ void Database::RemoveCallbacks() {
         debug_profile->finish();
         debug_profile = NULL;
     }
+    if (update_event) {
+        update_event->finish();
+        update_event = NULL;
+    }
 }
